version 8.2
clear
discard
set memory 10m
set more off
capture log close
cd D:\Home\jannb\Projekte\tools\stata\mrtab\London04

use drugs


*1) One-way tables

*Example: indicator mode

tabl inco1-inco7

mrtab inco1-inco7


*Note: Correct Denominator

mrtab inco1-inco7, include sort name(Sources of income)


*Same results: -tabstat-

tabstat inco1-inco7, s(sum mean) c(s)


*Note: response() option

tabl crime1-crime5

mrtab crime1-crime5, include r(1 3) name("Crime (as committer)") nonames

mrtab crime1-crime5, include r(2 3) name("Crime (as victim)") nonames


*Example: polytomous mode numeric

egen sum=rsum(inco1-inco7)
su sum, mean
local max=r(max)
drop sum
set seed 432879
forv i=1/`max' {
	gen pinco`i'=-1
	lab val pinco`i' inco
}
forv i=1/`=_N' {
	sortlistby2 1/7, random
	local list `r(list)'
	local k 1
	foreach j of local list {
		if inco`j'[`i']==1 {
			qui replace pinco`k++'=`j' if _n==`i'
		}
	}
}
lab def inco 1 "private support"  2 "public support" ///
 3 "dealing drugs" 4 "housebreaking/theft/robbery" ///
 5 "prostitution" 6 "'mischeln'/begging" ///
 7 "legal occupation" -1 "no further sources"
tabl pinco*

mrtab pinco1-pinco6, poly

mrtab pinco1-pinco6, poly response(1/7) include


*Example: polytomous mode string

foreach x of var pinco1-pinco6 {
 qui decode `x', gen(s`x')
 qui replace s`x'="" if s`x'=="no further sources"
 }
renpfix sp s
tabl sinco1-sinco6

mrtab sinco1-sinco6, poly include


*2) Two-way tables

*Example

mrtab inco1-inco7, include sort name(Sources of income) nonames ///
                   by(city) column


*Note: overall Test

mrtab inco1-inco7, include by(city) nofreq chi2 lrchi2 generate(X_)

list X_rp in 1/5, clean
drop X_*


*Note: multiple tests

mrtab inco1-inco7, include sort name(Sources of income) nonames ///
                   by(city) column mtest(bonferroni)


*Note: alternative tests

preserve
mrtab inco1-inco7, include nofreq generate(mr)
reshape long mr, i(id) j(R)
xi: logit mr i.R*i.city, cluster(id)
unab I : _Icity* _IRX*
test `I'
restore

preserve
mrtab inco1-inco7, include nofreq generate(mr)
reshape long mr, i(id) j(R)
xi: xtlogit mr i.R*i.city, re i(id)
estimates store A
xi: xtlogit mr i.R, re i(id)
lrtest A
restore


*3 Graphs

*Example: one-way graph

lab var crime3 "sex. harassment"
lab var crime4 "robbery"
mrgraph hbar crime1-crime5, include r(2 3) sort ///
 title("Crime experiences (as a victim)")


*Example: two-way graphs

*inboard
mrgraph hbar crime1-crime5, include r(2 3) sort by(sex) stat(column) ///
 title("Crime experiences (as a victim)")

*outboard
mrgraph hbar crime1-crime5, include r(2 3) sort by(sex) stat(column) ///
 bysep(outboard) title("Crime experiences (as a victim)")

*separate panels
mrgraph hbar crime1-crime5, include r(2 3) sort(1) by(sex) stat(column) ///
 bysep(separate, title("Crime experiences (as a victim)"))


*Example: tabplot

mrgraph tab crime1-crime5, include r(2 3) sort by(sex) stat(column) ///
 rtotal title("Crime experiences (as a victim)")


*Note: usage of -mrsvmat-

mrtab crime1-crime5, include r(2 3) by(sex) nofreq column
preserve
mrsvmat, stat(column) ctotal rtotal clear
list, clean
restore


*4 Misc

*fweights
mrtab inco1-inco7, include name(Sources of income)
preserve
drop id
contract inco1-inco7, f(pop)
count
mrtab inco1-inco7 [w=pop], include name(Sources of income)
restore

*by
bys city: mrtab inco1-inco7, include by(sex) non col nof name(Sources of income)

*if/in
tabl city
mrtab inco1-inco7 if city==1, include by(sex) non col nof name(Sources of income)

*aweights
set seed 32736
gen wt=4+invnorm(uniform())
su wt
mrtab inco1-inco7 [aw=wt], include name(Sources of income)
drop wt

*no labels
mrtab inco1-inco7, include nolabel

*break table
local mylsize : set linesize
set linesize 60
mrtab inco1-inco7, include by(city) non col nof name(Sources of income)
set linesize `mylsize'

*all kinds of percentages
mrtab inco1-inco7, include by(city) non cell column row rcell rcolumn

*countall
mrtab pinco1-pinco6, poly countall

exit
